======
tomita
======


.. image:: https://img.shields.io/pypi/v/python-tomita.svg
        :target: https://pypi.python.org/pypi/tomita

.. image:: https://img.shields.io/travis/python-g4brielvs/tomita.svg
        :target: https://travis-ci.com/g4brielvs/python-tomita

.. image:: https://readthedocs.org/projects/tomita/badge/?version=latest
        :target: https://tomita.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/g4brielvs/python-tomita/shield.svg
     :target: https://pyup.io/repos/github/g4brielvs/python-tomita
     :alt: Updates



*tomita* is a music and synthesizer package


* Free software: GNU General Public License v3
* Documentation: https://tomita.readthedocs.io.


Features
--------

* TODO